@@ -81,9 +81,11 @@ class CreateSecurityGroup(show.ShowOne):
 
         compute_client = self.app.client_manager.compute
 
+        description = parsed_args.description or parsed_args.name
+
         data = compute_client.security_groups.create(
             parsed_args.name,
-            parsed_args.description,
+            description,
         )
 
         info = {}
@@ -290,6 +292,7 @@ class CreateSecurityGroupRule(show.ShowOne):
         parser.add_argument(
             "--dst-port",
             metavar="<port-range>",
+            default=(0, 0),
             action=parseractions.RangeAction,
             help="Destination port, may be a range: 137:139 (default: 0; "
                  "only required for proto tcp and udp)",
